tw2.jqplugins.chosen
====================

Chosen is a JavaScript plugin that makes long,
unwieldy select boxes much more user-friendly.

For more information about Chosen, see the harvest website:
http://harvesthq.github.com/chosen/ or the Github repository
for chosen: https://github.com/harvesthq/chosen

Chosen is licensed under the MIT license and so is this
ToscaWidgets2 library.

The bundled version of Chosen in this project is v1.0.0.

Build Status
------------

.. |master| image:: https://secure.travis-ci.org/toscawidgets/tw2.jqplugins.chosen.png?branch=master
   :alt: Build Status - master branch
   :target: http://travis-ci.org/#!/toscawidgets/tw2.jqplugins.chosen

.. |develop| image:: https://secure.travis-ci.org/toscawidgets/tw2.jqplugins.chosen.png?branch=develop
   :alt: Build Status - develop branch
   :target: http://travis-ci.org/#!/toscawidgets/tw2.jqplugins.chosen

+----------+-----------+
| Branch   | Status    |
+==========+===========+
| master   | |master|  |
+----------+-----------+
| develop  | |develop| |
+----------+-----------+
